@@ -5,7 +5,6 @@
 #undef HAVE_STPCPY
 #undef USE_PYTHON
 #undef USE_DEBUG
-#undef USE_PTHREAD
 #undef USE_GNOME
 #undef USE_PERL
 #undef USE_PLUGIN
@@ -14,5 +13,4 @@
 #undef USE_MYGLIB
 #undef SOCKS
 #undef PREFIX
-#undef VERSION
-#undef PACKAGE
+#undef USING_LINUX
