@@ -398,8 +398,11 @@ load_config (void)
    if (fh != -1)
    {
       fstat (fh, &st);
-      cfg = malloc (st.st_size);
-      read (fh, cfg, st.st_size);
+      cfg = malloc (st.st_size + 1);
+      cfg[0] = 0;
+      i = read (fh, cfg, st.st_size);
+      if (i >= 0)
+         cfg[i] = 0;
       close (fh);
       i = 0;
       do
