@@ -303,7 +303,7 @@ ignore_load ()
    struct stat st;
    char *cfg, *my_cfg;
    char file[256];
-   int fh;
+   int fh, i;
 
    snprintf (file, sizeof file, "%s/ignore.conf", get_xdir ());
    fh = open (file, O_RDONLY);
@@ -312,8 +312,11 @@ ignore_load ()
       fstat (fh, &st);
       if (st.st_size)
       {
-         cfg = malloc (st.st_size);
-         read (fh, cfg, st.st_size);
+         cfg = malloc (st.st_size + 1);
+         cfg[0] = 0;
+         i = read (fh, cfg, st.st_size);
+         if (i >= 0)
+             cfg[i] = 0;
          my_cfg = cfg;
          while (my_cfg)
          {
