@@ -17,6 +17,7 @@
  */
 
 #include <string.h>
+#include <ctype.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <sys/time.h>
@@ -194,6 +195,9 @@ SearchNick (char *text, char *nicks)
 {
    char S[64];
    char *n;
+   char *p;
+   char *t;
+   size_t ns;
 
    if (nicks == NULL)
       return 0;
@@ -201,8 +205,16 @@ SearchNick (char *text, char *nicks)
    n = strtok (S, ",");
    while (n != NULL)
    {
-      if (nocasestrstr (text, n))
-         return 1;
+      t = text;
+      ns = strlen(n);
+      while ((p = nocasestrstr (t, n)))
+      {
+	 if ((p == text || !isalnum(*(p-1))) && !isalnum(*(p+ns)))
+	     return 1;
+
+	 t = p + 1;
+      }
+
       n = strtok (NULL, ",");
    }
    return 0;
@@ -235,7 +247,7 @@ channel_msg (struct server *serv, char *outbuf, char *chan, char *from, char *te
    } else
    {
 
-      if (nocasestrstr (text, serv->nick) || SearchNick (text, prefs.bluestring))
+      if (SearchNick (text, serv->nick) || SearchNick (text, prefs.bluestring))
       {
          if (EMIT_SIGNAL (XP_HIGHLIGHT, sess, chan, from, text, NULL, fromme) == 1)
             return;
@@ -837,6 +849,7 @@ stupidcode:
                case '-':
                   modes++;
                   goto stupidcode;
+               case 'h':
                case 'o':
                case 'v':
                case 'k':
@@ -854,6 +867,7 @@ stupidcode:
             {
                switch (modes[0])
                {
+               case 'h':
                case 'o':
                case 'v':
                case 'k':
@@ -1063,9 +1077,9 @@ process_line (struct session *sess, struct server *serv, char *buf)
       {
          buf += 7;
       }
-      if (!strncmp (buf, "PING :", 6))
+      if (!strncmp (buf, "PING ", 5))
       {
-         sprintf (outbuf, "PONG :%s\r\n", buf + 6);
+         sprintf (outbuf, "PONG %s\r\n", buf + 5);
          tcp_send (serv, outbuf);
          return;
       }
@@ -1284,13 +1298,13 @@ process_line (struct session *sess, struct server *serv, char *buf)
                break;
             case 376:
             case 422:          /* end of motd */
-               serv->end_of_motd = TRUE;
-               if (prefs.ip_from_server)
+               if (!serv->end_of_motd && prefs.ip_from_server)
                {
                   serv->skip_next_who = TRUE;
                   sprintf (outbuf, "WHO %s\r\n", serv->nick);
                   tcp_send (serv, outbuf);
                }
+               serv->end_of_motd = TRUE;
                set_default_modes (serv, outbuf);
                check_willjoin_channels (serv, outbuf);
                goto def;
@@ -1453,8 +1467,8 @@ process_line (struct session *sess, struct server *serv, char *buf)
                   if (*to)
                   {
                      char *msg = find_word_to_end (buf, 4) + 1;
-                     if (*msg)
-                     {
+                     /*if (*msg)
+                     {*/
                         if (strcmp (nick, serv->servername) == 0 ||
                             strchr (nick, '.'))
                         {
@@ -1466,7 +1480,7 @@ process_line (struct session *sess, struct server *serv, char *buf)
                            notice (serv, outbuf, to, nick, msg, ip);
                         }
                         return;
-                     }
+                     /*}*/
                   }
                }
                if (!strcmp ("PART", cmd))
