@@ -373,7 +373,7 @@ struct commands cmds[] =
    {"QUERY", cmd_query, 0, 0, "/QUERY <nick>, opens up a new privmsg window to someone\n"},
    {"QUIT", cmd_quit, 0, 0, "/QUIT [<reason>], disconnects from the current server\n"},
    {"QUOTE", cmd_quote, 1, 0, "/QUOTE <text>, sends the text in raw form to the server\n"},
-   {"RECONNECT", cmd_reconnect, 1, 0, "/RECONENCT, reconnects to the current server\n"},
+   {"RECONNECT", cmd_reconnect, 0, 0, "/RECONENCT, reconnects to the current server\n"},
 #ifdef USE_PLUGIN
    {"RMDLL", cmd_rmdll, 0, 0, "/RMDLL <dll name>, unloads a plugin\n"},
 #endif
@@ -634,10 +634,27 @@ cmd_ban (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 int
 cmd_clear (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-   fe_text_clear (sess);
+   GSList *list = sess_list;
+   char *reason = find_word_to_end (cmd, 2);
+
+   if (strncasecmp(reason, "all", 3) == 0)
+   {
+      while (list)
+      {
+         if (!((session *)list->data)->is_shell)
+            fe_text_clear (list->data);
+         list = list->next;
+      }
+   } else
+   {
+      fe_text_clear (sess);
+   }
+
    return TRUE;
 }
 
+
+
 int
 cmd_close (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
@@ -2410,6 +2427,9 @@ user_command (struct session *sess, char *cmd, char *word[], char *word_eol[])
                      i++;
                   }
                   break;
+               default:
+                  tbuf[j] = cmd[i];
+                  j++;
                }
             }
          }
