@@ -202,7 +202,11 @@ execute_perl (char *function, char *args)
       free (perl_cmd);
    perl_cmd = malloc (strlen (function) + strlen (args) * 2 + 10);
    sprintf (perl_cmd, "&%s('%s')", function, escape_quotes (args));
+#ifndef HAVE_PERL_EVAL_PV
    return (perl_eval_pv (perl_cmd, TRUE));
+#else
+   return (Perl_eval_pv (perl_cmd, TRUE));
+#endif
 }
 
 int 
@@ -246,7 +250,11 @@ perl_init (struct session *default_sess, int autoload)
    my_perl = perl_alloc ();
    perl_construct (my_perl);
    perl_parse (my_perl, NULL, 3, perl_args, NULL);
-   perl_eval_pv (load_file, TRUE);  /* crashes here on /unloadall !! */
+#ifndef HAVE_PERL_EVAL_PV
+   perl_eval_pv (load_file, TRUE);
+#else
+   Perl_eval_pv (load_file, TRUE);
+#endif
    perl_inbound_handlers = 0;
    perl_command_handlers = 0;
    perl_print_handlers = 0;
@@ -948,7 +956,7 @@ XS (XS_IRC_dcc_list)
       i++;
       XST_mIV (i, dcc->type);
       i++;
-      XST_mIV (i, dcc->stat);
+      XST_mIV (i, dcc->dccstat);
       i++;
       XST_mIV (i, dcc->cps);
       i++;
