@@ -1296,7 +1296,7 @@ display_event (char *i, struct session *sess, int numargs, char **args)
    oi = ii = len = d = a = 0;
 
    if (i == NULL)
-      abort ();
+      return;
 
    while (done_all == FALSE)
    {
@@ -1319,8 +1319,8 @@ display_event (char *i, struct session *sess, int numargs, char **args)
          a = i[ii++];
          if (a > numargs)
          {
-            printf ("XChat DEBUG: display_event: arg > numargs (%d %d %s), ABORTING\n", a, numargs, i);
-            abort ();
+            fprintf (stderr, "XChat DEBUG: display_event: arg > numargs (%d %d %s)\n", a, numargs, i);
+	     break;
          }
          ar = (int *) args[(int) a];
          if (ar == NULL)
