@@ -38,6 +38,8 @@
 #endif
 
 extern char *g_get_home_dir (void);
+extern int g_snprintf ( char *str, size_t n,
+                                const char *format, ... );
 
 
 #ifdef USE_DEBUG
@@ -331,6 +333,8 @@ strip_color (unsigned char *text)
    return new_str;
 }
 
+#ifdef USING_LINUX
+
 static void
 get_cpu_info (int *mhz, int *cpus)
 {
@@ -373,10 +377,14 @@ get_cpu_info (int *mhz, int *cpus)
       *cpus = 1;
 }
 
+#endif
+
 char *
 get_cpu_str (int color)
 {
+#ifdef USING_LINUX
    int mhz, cpus;
+#endif
    struct utsname un;
    static char *buf = NULL;
    static char *color_buf;
@@ -389,14 +397,16 @@ get_cpu_str (int color)
    color_buf = malloc (128);
 
    uname (&un);
-   get_cpu_info (&mhz, &cpus);
 
+#ifdef USING_LINUX
+   get_cpu_info (&mhz, &cpus);
    if (mhz)
       snprintf (color_buf, 128,
                (cpus == 1) ? "%s \00310%s \0032[\00310%s\0032/\00310%dMHz\0032]"
                            : "%s \00310%s \0032[\00310%s\0032/\00310%dMHz\0032/\00310SMP\0032]",
                un.sysname, un.release, un.machine, mhz);
    else
+#endif
       snprintf (color_buf, 128, "%s \00310%s \0032[\00310%s\0032]",
                 un.sysname, un.release, un.machine);
 
@@ -426,8 +436,47 @@ buf_get_line (char *ibuf, char **buf, int *position, int len)
    return 1;
 }
 
+#ifdef HAVE_FNMATCH
 
-/* borrowed from ircII */
+#define _GNU_SOURCE
+#include <fnmatch.h>
+
+#ifdef FNM_CASEFOLD
+
+int
+match (unsigned char *mask, unsigned char *string)
+{
+   if (fnmatch (mask, string, FNM_CASEFOLD) == 0)
+      return 1;
+
+   return 0;
+}
+
+#else
+
+int
+match (unsigned char *mask, unsigned char *string)
+{
+   int ret = 0;
+
+   mask = strdup (mask);
+   string = strdup (string);
+
+   tolowerStr (mask);      /* hack to make it case-insensitive */
+   tolowerStr (string);
+
+   if (fnmatch (mask, string, 0) == 0)
+      ret = 1;
+
+   free (mask);
+   free (string);
+
+   return ret;
+}
+
+#endif
+
+#else
 
 int
 match (unsigned char *mask, unsigned char *string)
@@ -535,6 +584,8 @@ match (unsigned char *mask, unsigned char *string)
    }
 }
 
+#endif
+
 int
 for_files (char *dirname, char *mask, void callback (char *file))
 {
