@@ -130,7 +130,7 @@ fe_dcc_update_recv (struct DCC *dcc)
    snprintf (perc, sizeof (perc), "%.0f%%", dcc->perc);
 
    gtk_clist_freeze (GTK_CLIST (dccrwin.list));
-   gtk_clist_set_text (GTK_CLIST (dccrwin.list), row, 0, dccstat[(int) dcc->stat].name);
+   gtk_clist_set_text (GTK_CLIST (dccrwin.list), row, 0, dccstat[(int) dcc->dccstat].name);
    gtk_clist_set_text (GTK_CLIST (dccrwin.list), row, 3, pos);
    gtk_clist_set_text (GTK_CLIST (dccrwin.list), row, 4, perc);
    gtk_clist_set_text (GTK_CLIST (dccrwin.list), row, 5, cps);
@@ -142,11 +142,11 @@ fe_dcc_update_recv (struct DCC *dcc)
    } else
       strcpy (eta, "--:--:--");
    gtk_clist_set_text (GTK_CLIST (dccrwin.list), row, 6, eta);
-   if (dccstat[(int) dcc->stat].color != 1)
+   if (dccstat[(int) dcc->dccstat].color != 1)
       gtk_clist_set_foreground
-         (GTK_CLIST (dccrwin.list), row, colors + dccstat[(int) dcc->stat].color);
+         (GTK_CLIST (dccrwin.list), row, colors + dccstat[(int) dcc->dccstat].color);
 #ifdef USE_GNOME
-   if (dcc->stat == STAT_DONE)
+   if (dcc->dccstat == STAT_DONE)
       gtk_clist_set_text (GTK_CLIST (dccrwin.list), row, 8, (char *) gnome_mime_type_of_file (dcc->destfile));
 #endif
    gtk_clist_thaw (GTK_CLIST (dccrwin.list));
@@ -179,10 +179,10 @@ fe_dcc_update_send (struct DCC *dcc)
    } else
       strcpy (eta, "--:--:--");
    gtk_clist_freeze (GTK_CLIST (dccswin.list));
-   gtk_clist_set_text (GTK_CLIST (dccswin.list), row, 0, dccstat[(int) dcc->stat].name);
-   if (dccstat[(int) dcc->stat].color != 1)
+   gtk_clist_set_text (GTK_CLIST (dccswin.list), row, 0, dccstat[(int) dcc->dccstat].name);
+   if (dccstat[(int) dcc->dccstat].color != 1)
       gtk_clist_set_foreground
-         (GTK_CLIST (dccswin.list), row, colors + dccstat[(int) dcc->stat].color);
+         (GTK_CLIST (dccswin.list), row, colors + dccstat[(int) dcc->dccstat].color);
    gtk_clist_set_text (GTK_CLIST (dccswin.list), row, 3, pos);
    gtk_clist_set_text (GTK_CLIST (dccswin.list), row, 4, ack);
    gtk_clist_set_text (GTK_CLIST (dccswin.list), row, 5, perc);
@@ -196,7 +196,7 @@ dcc_abort (struct DCC *dcc)
 {
    if (dcc)
    {
-      switch (dcc->stat)
+      switch (dcc->dccstat)
       {
       case STAT_QUEUED:
       case STAT_CONNECTING:
@@ -251,17 +251,17 @@ fe_dcc_update_recv_win (void)
       dcc = (struct DCC *) list->data;
       if (dcc->type == TYPE_RECV)
       {
-         nnew[0] = dccstat[(int) dcc->stat].name;
+         nnew[0] = dccstat[(int) dcc->dccstat].name;
          nnew[1] = dcc->file;
          nnew[7] = dcc->nick;
 #ifdef USE_GNOME
-         if (dcc->stat == STAT_DONE)
+         if (dcc->dccstat == STAT_DONE)
             nnew[8] = (char *) gnome_mime_type_of_file (dcc->destfile);
          else
             nnew[8] = "";
 #endif
          sprintf (size, "%lu", dcc->size);
-         if (dcc->stat == STAT_QUEUED)
+         if (dcc->dccstat == STAT_QUEUED)
             sprintf (pos, "%lu", dcc->resumable);
          else
             sprintf (pos, "%lu", dcc->pos);
@@ -276,10 +276,10 @@ fe_dcc_update_recv_win (void)
             strcpy (eta, "--:--:--");
          row = gtk_clist_append (GTK_CLIST (dccrwin.list), nnew);
          gtk_clist_set_row_data (GTK_CLIST (dccrwin.list), row, (gpointer) dcc);
-         if (dccstat[(int) dcc->stat].color != 1)
+         if (dccstat[(int) dcc->dccstat].color != 1)
             gtk_clist_set_foreground (
                                         GTK_CLIST (dccrwin.list), row,
-                                        colors + dccstat[(int) dcc->stat].color);
+                                        colors + dccstat[(int) dcc->dccstat].color);
       }
       list = list->next;
    }
@@ -381,7 +381,7 @@ open_clicked (void)
    if (row != -1)
    {
       dcc = gtk_clist_get_row_data (GTK_CLIST (dccrwin.list), row);
-      if (dcc && dcc->stat == STAT_DONE)
+      if (dcc && dcc->dccstat == STAT_DONE)
       {
          mime_type = (char *)gnome_mime_type (dcc->destfile);
          if (mime_type)
@@ -525,7 +525,7 @@ fe_dcc_update_send_win (void)
       dcc = (struct DCC *) list->data;
       if (dcc->type == TYPE_SEND)
       {
-         nnew[0] = dccstat[(int) dcc->stat].name;
+         nnew[0] = dccstat[(int) dcc->dccstat].name;
          nnew[1] = file_part (dcc->file);
          nnew[8] = dcc->nick;
          snprintf (size, sizeof (size), "%lu", dcc->size);
@@ -545,11 +545,11 @@ fe_dcc_update_send_win (void)
             strcpy (eta, "--:--:--");
          row = gtk_clist_append (GTK_CLIST (dccswin.list), nnew);
          gtk_clist_set_row_data (GTK_CLIST (dccswin.list), row, (gpointer) dcc);
-         if (dccstat[(int) dcc->stat].color != 1)
+         if (dccstat[(int) dcc->dccstat].color != 1)
             gtk_clist_set_foreground
                (
                   GTK_CLIST (dccswin.list), row,
-                  colors + dccstat[(int) dcc->stat].color);
+                  colors + dccstat[(int) dcc->dccstat].color);
       }
       list = list->next;
    }
@@ -568,7 +568,7 @@ send_row_selected (GtkWidget * clist, gint row, gint column,
       dcc = gtk_clist_get_row_data (GTK_CLIST (clist), row);
       if (dcc)
       {
-         switch (dcc->stat)
+         switch (dcc->dccstat)
          {
          case STAT_FAILED:
          case STAT_ABORTED:
@@ -668,7 +668,7 @@ accept_chat_clicked (GtkWidget * wid, gpointer none)
    {
       dcc = gtk_clist_get_row_data (GTK_CLIST (dcccwin.list), row);
       gtk_clist_unselect_row (GTK_CLIST (dcccwin.list), row, 0);
-      switch (dcc->stat)
+      switch (dcc->dccstat)
       {
       case STAT_QUEUED:
          if (dcc->type == TYPE_CHATRECV)
@@ -729,7 +729,7 @@ fe_dcc_update_chat_win (void)
       dcc = (struct DCC *) list->data;
       if ((dcc->type == TYPE_CHATSEND || dcc->type == TYPE_CHATRECV))
       {
-         nnew[0] = dccstat[(int) dcc->stat].name;
+         nnew[0] = dccstat[(int) dcc->dccstat].name;
          nnew[1] = dcc->nick;
          sprintf (pos, "%lu", dcc->pos);
          sprintf (siz, "%lu", dcc->size);
