@@ -1116,7 +1116,13 @@ key_action_page_switch (GtkWidget * wid, GdkEventKey * evt, char *d1, char *d2,
       gtk_notebook_set_page (GTK_NOTEBOOK (main_book), num);
    else
    {
-      gtk_notebook_set_page (GTK_NOTEBOOK (main_book), gtk_notebook_get_current_page (GTK_NOTEBOOK (main_book)) + num);
+      len = g_list_length ( ((GtkNotebook *) main_book)->children);
+      i = gtk_notebook_get_current_page (GTK_NOTEBOOK (main_book)) + num;
+      if (i >= len)
+         i = 0;
+      if (i < 0)
+	 i = len - 1;
+      gtk_notebook_set_page (GTK_NOTEBOOK (main_book), i);
    }
    return 0;
 }
@@ -1487,16 +1493,18 @@ tab_comp_cmd (GtkWidget * t)
             snprintf (lcmd, sizeof (lcmd), "%s", last);
          } else if (last > (char *) 1)
          {
-            PrintText (sess, last);
+            snprintf (buf, sizeof (buf), "%s %s ", last, pop->name);
+            PrintText (sess, buf);
+            /*PrintText (sess, last);
             PrintText (sess, "\t");
             PrintText (sess, pop->name);
-            PrintText (sess, "\t");
+            PrintText (sess, "\t");*/
             last = (void *) 1;
             tab_comp_find_common (lcmd, pop->name);
          } else if (last == (void *) 1)
          {
             PrintText (sess, pop->name);
-            PrintText (sess, "\t");
+            /*PrintText (sess, "\t");*/
             tab_comp_find_common (lcmd, pop->name);
          }
       }
@@ -1521,16 +1529,19 @@ tab_comp_cmd (GtkWidget * t)
             snprintf (lcmd, sizeof (lcmd), "%s", last);
          } else if (last > (char *) 1)
          {
-            PrintText (sess, last);
+            snprintf (buf, sizeof (buf), "%s %s ", last, cmd);
+            PrintText (sess, buf);
+            /*PrintText (sess, last);
             PrintText (sess, "\t");
             PrintText (sess, cmd);
-            PrintText (sess, "\t");
+            PrintText (sess, "\t");*/
             last = (void *) 1;
             tab_comp_find_common (lcmd, cmd);
          } else if (last == (void *) 1)
          {
             PrintText (sess, cmd);
-            PrintText (sess, "\t");
+            /*PrintText (sess, cmd);
+            PrintText (sess, "\t");*/
             tab_comp_find_common (lcmd, cmd);
          }
       }
