@@ -806,8 +806,16 @@ maingui_word_clicked (GtkXText *xtext, char *word, GdkEventButton *even, session
 void
 maingui_configure (GtkWidget *unused)
 {
-   if (menu_sess)
-      gtk_widget_queue_draw (menu_sess->gui->textgad);
+	if (menu_sess)
+	{
+		if (!menu_sess->is_shell)
+		{
+			if (((GtkXText *) menu_sess->gui->textgad)->transparent)
+			{
+				gtk_widget_queue_draw (menu_sess->gui->textgad);
+			}
+		}
+	}
 }
 
 static void
