@@ -224,7 +224,7 @@ load_serverentrys (void)
 {
    struct slentry serv;
    struct stat st;
-   int fh;
+   int fh, i;
    char *cfg, *my_cfg;
    char file[256];
    char buf[10];
@@ -239,8 +239,11 @@ load_serverentrys (void)
          add_defaults ();
       } else
       {
-         cfg = malloc (st.st_size);
-         read (fh, cfg, st.st_size);
+         cfg = malloc (st.st_size + 1);
+         cfg[0] = 0;
+         i = read (fh, cfg, st.st_size);
+         if (i >= 0)
+            cfg[i] = 0;
          my_cfg = cfg;
          my_cfg = cfg_get_str (my_cfg, "connecttab ", &buf[0]); /* legacy */
          if (!my_cfg)
