@@ -1146,16 +1146,14 @@ gtk_xtext_class_init (GtkXTextClass *class)
    xtext_class = (GtkXTextClass*) class;
 
    parent_class = gtk_type_class (gtk_widget_get_type ());
-
-   xtext_signals[WORD_CLICK] =
-    gtk_signal_new ("word_click",
-                    GTK_RUN_FIRST,
-                    object_class->type,
-                    GTK_SIGNAL_OFFSET (GtkXTextClass, word_click),
-			           gtk_marshal_NONE__INT_POINTER,
-			           GTK_TYPE_NONE, 2,
-			           GTK_TYPE_INT,
-			           GTK_TYPE_STRING);
+	xtext_signals[WORD_CLICK] =
+		gtk_signal_new (/*name*/"word_click",
+							 /*GtkSignalRunType*/GTK_RUN_FIRST,
+							 /*GtkType*/object_class->type,
+							 /*funcoffset*/GTK_SIGNAL_OFFSET (GtkXTextClass, word_click),
+							 /*GtkSignalMarshaller*/gtk_marshal_NONE__POINTER_POINTER,
+							 /*returnval*/GTK_TYPE_NONE,
+							 /*num args*/2, /*args*/GTK_TYPE_POINTER, GTK_TYPE_POINTER);
    gtk_object_class_add_signals (object_class, xtext_signals, LAST_SIGNAL);
 
    object_class->destroy = gtk_xtext_destroy;
@@ -1651,16 +1649,19 @@ get_desktop_window (Window the_window)
     if (nchildren) 
       XFree(children);
 
-    if (prop != None) {
+    if (prop != None)
+    {
       XGetWindowProperty(GDK_DISPLAY(), w, prop, 0L, 1L, False, AnyPropertyType,
 			 &type, &format, &length, &after, &data);
-    } else if (prop2 != None) {
+    } else
+    {
       XGetWindowProperty(GDK_DISPLAY(), w, prop2, 0L, 1L, False, AnyPropertyType,
 			 &type, &format, &length, &after, &data);
-    } else  {
-      continue;
     }
-    
+
+    if (data)
+      XFree (data);
+
     if (type != None) {
       return (desktop_window = w);
     }
